==> spip_3.1.4.orig.tar.xz: spip/ecrire/lang/public_uk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/public?lang_cible=uk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Головна',
	'article' => 'Стаття',
	'articles' => 'Статті',
	'articles_auteur' => 'Статті автора',
	'articles_populaires' => 'Статті, що найчастіше читають',
	'articles_rubrique' => 'Статті цієї рубрики',
	'aucun_article' => 'Статей нема',
	'aucun_auteur' => 'Авторів нема',
	'aucun_site' => 'Сайтів нема',
	'aucune_breve' => 'Новин нема',
	'aucune_rubrique' => 'Рубрик нема',
	'auteur' => 'Автор',
	'autres' => 'Інші',
	'autres_breves' => 'Інші новини',
	'autres_groupes_mots_clefs' => 'Інші групи ключових слів',
	'autres_sites' => 'Інші сайти',

	// B
	'bonjour' => 'Привіт',

	// C
	'commenter_site' => 'Коментарі до цього сайту',
	'contact' => 'Контакти',
	'copie_document_impossible' => 'Неможливо скопіювати документ',

	// D
	'date' => 'Дата',
	'dernier_ajout' => 'Останнє оновлення',
	'dernieres_breves' => 'Свіжі новини',
	'derniers_articles' => 'Нові статті',
	'derniers_commentaires' => 'Нові коментарі',
	'derniers_messages_forum' => 'Нові повідомлення на форумі',

	// E
	'edition_mode_texte' => 'Текстовий режим',
	'en_reponse' => 'Коментар до:',
	'en_resume' => 'Резюме',
	'envoyer_message' => 'Відправити повідомлення',
	'espace_prive' => 'Адміністративна частина',

	// F
	'formats_acceptes' => 'Припустимі формати: @formats@.',

	// H
	'hierarchie_site' => 'Карта сайту',

	// J
	'jours' => 'дні',

	// L
	'lien_connecter' => 'Увійти',

	// M
	'meme_auteur' => 'Цього автора',
	'meme_rubrique' => 'Ще в рубриці',
	'memes_auteurs' => 'Тими самими авторами',
	'message' => 'Повідомлення',
	'messages_forum' => 'Повідомлення форуму',
	'messages_recents' => 'Нові повідомлення форуму',
	'mots_clef' => 'Ключове слово',
	'mots_clefs' => 'Ключові слова',
	'mots_clefs_meme_groupe' => 'Ключові слова з цієї групи',

	// N
	'navigation' => 'Дивитись',
	'nom' => 'Ім’я',
	'nouveautes' => 'Що є нове',
	'nouveautes_web' => 'Що є нове в сайтах',
	'nouveaux_articles' => 'Нові статті',
	'nouvelles_breves' => 'Свіжі новини',

	// P
	'page_precedente' => 'попередня сторінка',
	'page_suivante' => 'наступна сторінка',
	'par_auteur' => ' ',
	'participer_site' => 'Ви можете прийняти активну участь в житті цього сайту і писати свої статті. Усе, що потрібно зробити, - зареєструватися.',
	'plan_site' => 'Карта сайту',
	'popularite' => 'Популярність',
	'poster_message' => 'Відправити повідомлення',
	'proposer_site' => 'Ви можете запропонувати додати сайт до цього рубрику:',

	// R
	'repondre_article' => 'Залишити коментар ',
	'repondre_breve' => 'Залишити коментар ',
	'resultats_recherche' => 'Результати пошуку',
	'retour_debut_forums' => 'Усі форуми',
	'rubrique' => 'Розділ',
	'rubriques' => 'Розділи',

	// S
	'signatures_petition' => 'Підписи',
	'site_realise_avec_spip' => 'Сайт працює на SPIP',
	'sites_web' => 'Сайти',
	'sous_rubriques' => 'Підрубрики',
	'spam' => 'Спам',
	'suite' => 'далі',
	'sur_web' => 'В інтернеті',
	'syndiquer_rubrique' => 'RSS цього рубрику',
	'syndiquer_site' => 'RSS всього сайту',

	// T
	'texte_lettre_information' => 'Інформаційний бюлетень сайту',
	'texte_lettre_information_2' => 'Матеріали на сайті розміщуються з',

	// V
	'ver_imprimer' => 'Версія для друку',
	'voir_en_ligne' => 'Див. онлайн',
	'voir_squelette' => 'Показати шаблон цієї сторінки'
);

?>

==> spip_3.2.4.orig.tar.xz: spip/ecrire/lang/public_uk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=uk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Головна',
	'article' => 'Стаття',
	'articles' => 'Статті',
	'articles_auteur' => 'Статті автора',
	'articles_populaires' => 'Статті, що найчастіше читають',
	'articles_rubrique' => 'Статті розділу',
	'aucun_article' => 'Статей немає',
	'aucun_auteur' => 'Авторів немає',
	'aucun_site' => 'Сайтів немає',
	'aucune_breve' => 'Новин немає',
	'aucune_rubrique' => 'Розділів немає',
	'auteur' => 'Автор',
	'autres' => 'Інші',
	'autres_breves' => 'Інші новини',
	'autres_groupes_mots_clefs' => 'Інші групи ключових слів',
	'autres_sites' => 'Інші сайти',

	// B
	'bonjour' => 'Привіт',

	// C
	'commenter_site' => 'Коментарі до сайту',
	'contact' => 'Контакти',
	'copie_document_impossible' => 'Неможливо скопіювати документ',

	// D
	'date' => 'Дата',
	'dernier_ajout' => 'Останнє оновлення',
	'dernieres_breves' => 'Свіжі новини',
	'derniers_articles' => 'Нові статті',
	'derniers_commentaires' => 'Нові коментарі',
	'derniers_messages_forum' => 'Нові повідомлення на форумі',

	// E
	'edition_mode_texte' => 'Текстовий режим',
	'en_reponse' => 'Коментар до:',
	'en_resume' => 'Підсумки',
	'envoyer_message' => 'Відправити повідомлення',
	'espace_prive' => 'Адміністративна частина',

	// F
	'formats_acceptes' => 'Припустимі формати: @formats@.',

	// H
	'hierarchie_site' => 'Карта сайту',

	// J
	'jours' => 'дні',

	// L
	'lien_connecter' => 'Увійти',

	// M
	'meme_auteur' => 'Цього автора',
	'meme_rubrique' => 'Ще в розділі',
	'memes_auteurs' => 'Тими самими авторами',
	'message' => 'Повідомлення',
	'messages_forum' => 'Повідомлення форуму',
	'messages_recents' => 'Нові повідомлення форуму',
	'mots_clef' => 'Ключове слово',
	'mots_clefs' => 'Ключові слова',
	'mots_clefs_meme_groupe' => 'Ключові слова з групи',

	// N
	'navigation' => 'Дивитись',
	'nom' => 'Ім’я',
	'nouveautes' => 'Що є нове',
	'nouveautes_web' => 'Що є нове в сайтах',
	'nouveaux_articles' => 'Нові статті',
	'nouvelles_breves' => 'Свіжі новини',

	// P
	'page_precedente' => 'попередня сторінка',
	'page_suivante' => 'наступна сторінка',
	'par_auteur' => ' ',
	'participer_site' => 'Ви можете прийняти активну участь в житті цього сайту і писати свої статті. Усе, що потрібно зробити, - зареєструватися.',
	'plan_site' => 'Карта сайту',
	'popularite' => 'Популярність',
	'poster_message' => 'Відправити повідомлення',
	'proposer_site' => 'Ви можете запропонувати додати сайт до цього рубрику:',

	// R
	'repondre_article' => 'Залишити коментар ',
	'repondre_breve' => 'Залишити коментар ',
	'resultats_recherche' => 'Результати пошуку',
	'retour_debut_forums' => 'Усі форуми',
	'rubrique' => 'Розділ',
	'rubriques' => 'Розділи',

	// S
	'signatures_petition' => 'Підписи',
	'site_realise_avec_spip' => 'Сайт працює на SPIP',
	'sites_web' => 'Сайти',
	'sous_rubriques' => 'Підрубрики',
	'spam' => 'Спам',
	'suite' => 'далі',
	'sur_web' => 'В інтернеті',
	'syndiquer_rubrique' => 'RSS цього рубрику',
	'syndiquer_site' => 'RSS всього сайту',

	// T
	'texte_lettre_information' => 'Інформаційний бюлетень сайту',
	'texte_lettre_information_2' => 'Матеріали на сайті розміщуються з',

	// V
	'ver_imprimer' => 'Версія для друку',
	'voir_en_ligne' => 'Див. онлайн',
	'voir_squelette' => 'Показати шаблон сторінки'
);
